==> openmw_0.44.0.orig.tar.gz: openmw-openmw-0.44.0/AUTHORS.md <==
Contributors
============

The OpenMW project was started in 2008 by Nicolay Korslund.
In the course of years many people have contributed to the project.

If you feel your name is missing from this list, please notify a developer.


Programmers
-----------

    Marc Zinnschlag (Zini) - Lead Programmer/Project Manager

    Adam Hogan (aurix)
    Aesylwinn
    aegis
    AHSauge
    Aleksandar Jovanov
    Alex Haddad (rainChu)
    Alex McKibben
    alexanderkjall
    Alexander Nadeau (wareya)
    Alexander Olofsson (Ace)
    Allofich
    Andrei Kortunov (akortunov)
    AnyOldName3
    Aussiemon
    Austin Salgat (Salgat)
    Artem Kotsynyak (greye)
    artemutin
    Arthur Moore (EmperorArthur)
    Assumeru
    athile
    Ben Shealy (bentsherman)
    Bret Curtis (psi29a)
    Britt Mathis (galdor557)
    Capostrophic
    cc9cii
    Chris Boyce (slothlife)
    Chris Robinson (KittyCat)
    Cory F. Cohen (cfcohen)
    Cris Mihalache (Mirceam)
    crussell187
    DanielVukelich
    darkf
    David Cernat (davidcernat)
    devnexen
    Dieho
    Dmitry Shkurskiy (endorph)
    Douglas Diniz (Dgdiniz)
    Douglas Mencken (dougmencken)
    dreamer-dead
    David Teviotdale (dteviot)
    Edmondo Tommasina (edmondo)
    Eduard Cot (trombonecot)
    Eli2
    elsid
    Emanuel Guével (potatoesmaster)
    eroen
    escondida
    Evgeniy Mineev (sandstranger)
    Federico Guerra (FedeWar)
    Fil Krynicki (filkry)
    Gašper Sedej
    gugus/gus
    Hallfaer Tuilinn
    Haoda Wang (h313)
    hristoast
    Internecine
    Jacob Essex (Yacoby)    
    Jake Westrip (16bitint)
    Jason Hooks (jhooks)
    jeaye
    Jeffrey Haines (Jyby)
    Jengerer
    Jiří Kuneš (kunesj)
    Joe Wilkerson (neuralroberts)
    Joel Graff (graffy)
    John Blomberg (fstp)
    Jordan Ayers
    Jordan Milne
    Jules Blok (Armada651)
    julianko
    Julien Voisin (jvoisin/ap0)
    Karl-Felix Glatzer (k1ll)
    Kevin Poitra (PuppyKevin)
    Koncord
    Kurnevsky Evgeny (kurnevsky)
    Lars Söderberg (Lazaroth)
    lazydev
    Leon Krieg (lkrieg)
    Leon Saunders (emoose)
    Łukasz Gołębiewski (lukago)
    logzero
    lohikaarme
    Lukasz Gromanowski (lgro)
    Manuel Edelmann (vorenon)
    Marc Bouvier (CramitDeFrog)
    Marcin Hulist (Gohan)
    Mark Siewert (mark76)
    Marco Melletti (mellotanica)
    Marco Schulze
    Martin Otto (MAtahualpa)
    Mateusz Kołaczek (PL_kolek)
    Mateusz Malisz (malice)
    megaton
    Michael Hogan (Xethik)
    Michael Mc Donnell
    Michael Papageorgiou (werdanith)
    Michał Bień (Glorf)
    Michał Moroz (dragonee)
    Miloslav Číž (drummyfish)
    Miroslav Puda (pakanek)
    MiroslavR
    Mitchell Schwitzer (schwitzerm)
    naclander
    Narmo
    Nathan Jeffords (blunted2night)
    NeveHanter
    Nialsy
    Nikolay Kasyanov (corristo)
    nobrakal
    Nolan Poe (nopoe)
    Oleg Chkan (mrcheko)
    Paul Cercueil (pcercuei)
    Paul McElroy (Greendogo)
    Pi03k
    Pieter van der Kloet (pvdk)
    pkubik
    PlutonicOverkill
    Radu-Marius Popovici (rpopovici)
    Rafael Moura (dhustkoder)
    rdimesio
    rexelion
    riothamus
    Rob Cutmore (rcutmore)
    Robert MacGregor (Ragora)
    Rohit Nirmal
    Roman Melnik (Kromgart)
    Roman Proskuryakov (kpp)
    Sandy Carter (bwrsandman)
    Scott Howard
    scrawl
    Sebastian Wick (swick)
    Sergey Shambir
    ShadowRadiance
    Siimacore
    sir_herrbatka
    smbas
    spycrab
    Stefan Galowicz (bogglez)
    Stanislav Bobrov (Jiub)
    stil-t
    svaante
    Sylvain Thesnieres (Garvek)
    t6
    terrorfisch
    thegriglat
    Thomas Luppi (Digmaster)
    tri4ng1e
    unelsson
    Will Herrmann (Thunderforge)
    Tom Mason (wheybags)
    Torben Leif Carrington (TorbenC)
    viadanna
    Vincent Heuken
    vocollapse
    zelurker

Documentation
-------------

    Alejandro Sanchez (HiPhish)
    Bodillium
    Bret Curtis (psi29a)
    Cramal
    Ryan Tucker (Ravenwing)
    sir_herrbatka

Packagers
---------

    Alexander Olofsson (Ace) - Windows
    Bret Curtis (psi29a) - Debian and Ubuntu Linux
    Edmondo Tommasina (edmondo) - Gentoo Linux
    Julian Ospald (hasufell) - Gentoo Linux
    Karl-Felix Glatzer (k1ll) - Linux Binaries
    Kenny Armstrong (artorius) - Fedora Linux
    Nikolay Kasyanov (corristo) - Mac OS X
    Sandy Carter (bwrsandman) - Arch Linux

Public Relations and Translations
---------------------------------

    Artem Kotsynyak (greye) - Russian News Writer
    Dawid Lakomy (Vedyimyn) - Polish News Writer
    Jim Clauwaert (Zedd) - Public Outreach
    Julien Voisin (jvoisin/ap0) - French News Writer
    Lukasz Gromanowski (lgro) - English News Writer
    Martin Otto (Atahualpa) - Podcaster, Public Outreach, German Translator
    Mickey Lyle (raevol) - Release Manager
    Pithorn - Chinese News Writer
    sir_herrbatka - Polish News Writer
    Tom Koenderink (Okulo) - English News Writer

Website
-------

    Lukasz Gromanowski (Lgro) - Website Administrator
    Ryan Sardonic (Wry) - Wiki Editor
    sir_herrbatka - Forum Administrator

Formula Research
----------------

    Hrnchamd
    Epsilon
    fragonard
    Greendogo
    HiPhish
    modred11
    Myckel
    natirips
    Sadler

Artwork
-------

    Necrod - OpenMW Logo
    Mickey Lyle (raevol) - Wordpress Theme
    Tom Koenderink (Okulo), SirHerrbatka, crysthala, Shnatsel, Lamoot - OpenMW Editor Icons

Inactive Contributors
---------------------

    Ardekantur
    Armin Preiml
    Berulacks
    Carl Maxwell
    Diggory Hardy
    Dmitry Marakasov (AMDmi3)
    ElderTroll
    guidoj
    Jan-Peter Nilsson (peppe)
    Jan Borsodi
    Josua Grawitter
    juanmnzsk8
    Kingpix
    Lordrea
    Michal Sciubidlo
    Nicolay Korslund
    Nekochan
    pchan3
    penguinroad
    sergoz
    spyboot
    Star-Demon
    Thoronador
    Yuri Krupenin

Additional Credits
------------------
In this section we would like to thank people not part of OpenMW for their work.

Thanks to Maxim Nikolaev,
for allowing us to use his excellent Morrowind fan-art on our website and in other places.

Thanks to DokterDume,
for kindly providing us with the Moon and Star logo, used as the application icon and project logo.

Thanks to Kevin Ryan,
for creating the icon used for the Data Files tab of the OpenMW Launcher.

Thanks to DejaVu team,
for their DejaVuLGCSansMono fontface, see DejaVu Font License.txt for their license terms.

==> openmw_0.46.0.orig.tar.gz: openmw-openmw-0.46.0/AUTHORS.md <==
Contributors
============

The OpenMW project was started in 2008 by Nicolay Korslund.
In the course of years many people have contributed to the project.

If you feel your name is missing from this list, please notify a developer.


Programmers
-----------

    Marc Zinnschlag (Zini) - Lead Programmer/Project Manager

    Adam Hogan (aurix)
    Aesylwinn
    aegis
    AHSauge
    Aleksandar Jovanov
    Alex Haddad (rainChu)
    Alex McKibben
    alexanderkjall
    Alexander Nadeau (wareya)
    Alexander Olofsson (Ace)
    Alex Rice
    Alex S (docwest)
    Allofich
    Andrei Kortunov (akortunov)
    AnyOldName3
    Ardekantur
    Armin Preiml
    Artem Kotsynyak (greye)
    Artem Nykolenko (anikm21)
    artemutin
    Arthur Moore (EmperorArthur)
    Assumeru
    athile
    Aussiemon
    Austin Salgat (Salgat)
    Ben Shealy (bentsherman)
    Berulacks
    Bret Curtis (psi29a)
    Britt Mathis (galdor557)
    Capostrophic
    Carl Maxwell
    cc9cii
    Cédric Mocquillon
    Chris Boyce (slothlife)
    Chris Robinson (KittyCat)
    Cory F. Cohen (cfcohen)
    Cris Mihalache (Mirceam)
    crussell187
    DanielVukelich
    darkf
    David Cernat (davidcernat)
    Declan Millar (declan-millar)
    devnexen
    Dieho
    Dmitry Shkurskiy (endorph)
    Douglas Diniz (Dgdiniz)
    Douglas Mencken (dougmencken)
    dreamer-dead
    David Teviotdale (dteviot)
    Diggory Hardy
    Dmitry Marakasov (AMDmi3)
    Edmondo Tommasina (edmondo)
    Eduard Cot (trombonecot)
    Eli2
    Emanuel Guével (potatoesmaster)
    eroen
    escondida
    Evgeniy Mineev (sandstranger)
    Federico Guerra (FedeWar)
    Fil Krynicki (filkry)
    Finbar Crago (finbar-crago)
    Florian Weber (Florianjw)
    Frédéric Chardon (fr3dz10)
    Gaëtan Dezeiraud (Brouilles)
    Gašper Sedej
    Gijsbert ter Horst (Ghostbird)
    Gohan1989
    gugus/gus
    guidoj
    Haoda Wang (h313)
    hristoast
    Internecine
    Jackerty
    Jacob Essex (Yacoby)
    Jake Westrip (16bitint)
    James Carty (MrTopCat)
    James Moore (moore.work)
    James Stephens (james-h-stephens)
    Jan-Peter Nilsson (peppe)
    Jan Borsodi (am0s)
    Jason Hooks (jhooks)
    jeaye
    Jeffrey Haines (Jyby)
    Jengerer
    Jiří Kuneš (kunesj)
    Joe Wilkerson (neuralroberts)
    Joel Graff (graffy)
    John Blomberg (fstp)
    Jordan Ayers
    Jordan Milne
    Josua Grawitter
    Jules Blok (Armada651)
    julianko
    Julien Voisin (jvoisin/ap0)
    Karl-Felix Glatzer (k1ll)
    Kevin Poitra (PuppyKevin)
    Koncord
    Kurnevsky Evgeny (kurnevsky)
    Lars Söderberg (Lazaroth)
    lazydev
    Leon Krieg (lkrieg)
    Leon Saunders (emoose)
    logzero
    lohikaarme
    Lordrea
    Łukasz Gołębiewski (lukago)
    Lukasz Gromanowski (lgro)
    Manuel Edelmann (vorenon)
    Marc Bouvier (CramitDeFrog)
    Marcin Hulist (Gohan)
    Mark Siewert (mark76)
    Marco Melletti (mellotanica)
    Marco Schulze
    Martin Otto (MAtahualpa)
    Mateusz Kołaczek (PL_kolek)
    Mateusz Malisz (malice)
    megaton
    Michael Hogan (Xethik)
    Michael Mc Donnell
    Michael Papageorgiou (werdanith)
    Michael Stopa (Stomy)
    Michał Ściubidło (mike-sc)
    Michał Bień (Glorf)
    Michał Moroz (dragonee)
    Miloslav Číž (drummyfish)
    Miroslav Puda (pakanek)
    MiroslavR
    Mitchell Schwitzer (schwitzerm)
    naclander
    Narmo
    Nat Meo (Utopium)
    Nathan Jeffords (blunted2night)
    NeveHanter
    Nialsy
    Nicolay Korslund
    Nikolay Kasyanov (corristo)
    nobrakal
    Nolan Poe (nopoe)
    Oleg Chkan (mrcheko)
    Paul Cercueil (pcercuei)
    Paul McElroy (Greendogo)
    pchan3
    Perry Hugh
    Phillip Andrews (PhillipAnd)
    Pi03k
    Pieter van der Kloet (pvdk)
    pkubik
    PLkolek
    PlutonicOverkill
    Radu-Marius Popovici (rpopovici)
    Rafael Moura (dhustkoder)
    rdimesio
    rexelion
    riothamus
    Rob Cutmore (rcutmore)
    Robert MacGregor (Ragora)
    Rohit Nirmal
    Roman Melnik (Kromgart)
    Roman Proskuryakov (kpp)
    Roman Siromakha (elsid)
    Sandy Carter (bwrsandman)
    Scott Howard (maqifrnswa)
    scrawl
    Sebastian Wick (swick)
    Sergey Fukanchik
    Sergey Shambir (sergey-shambir)
    sergoz
    ShadowRadiance
    Siimacore
    sir_herrbatka
    smbas
    Sophie Kirschner (pineapplemachine)
    spycrab
    Stefan Galowicz (bogglez)
    Stanislav Bobrov (Jiub)
    Stanislaw Halik (sthalik)
    Star-Demon
    stil-t
    svaante
    Sylvain Thesnieres (Garvek)
    t6
    terrorfisch
    thegriglat
    Thomas Luppi (Digmaster)
    tlmullis
    tri4ng1e
    Thoronador
    Tom Mason (wheybags)
    Torben Leif Carrington (TorbenC)
    unelsson
    uramer
    viadanna
    Vincent Heuken
    Vladimir Panteleev (CyberShadow)
    Wang Ryu (bzzt)
    Will Herrmann (Thunderforge)
    vocollapse
    xyzz
    Yohaulticetl
    Yuri Krupenin
    zelurker

Documentation
-------------

    Adam Bowen (adamnbowen)
    Alejandro Sanchez (HiPhish)
    Bodillium
    Bret Curtis (psi29a)
    Cramal
    David Walley (Loriel)
    Diego Crespo
    Joakim Berg (lysol90)
    Ryan Tucker (Ravenwing)
    sir_herrbatka

Packagers
---------

    Alexander Olofsson (Ace) - Windows
    Bret Curtis (psi29a) - Debian and Ubuntu Linux
    Edmondo Tommasina (edmondo) - Gentoo Linux
    Julian Ospald (hasufell) - Gentoo Linux
    Karl-Felix Glatzer (k1ll) - Linux Binaries
    Kenny Armstrong (artorius) - Fedora Linux
    Nikolay Kasyanov (corristo) - Mac OS X
    Sandy Carter (bwrsandman) - Arch Linux

Public Relations and Translations
---------------------------------

    Artem Kotsynyak (greye) - Russian News Writer
    Dawid Lakomy (Vedyimyn) - Polish News Writer
    ElderTroll - Release Manager
    Jim Clauwaert (Zedd) - Public Outreach
    juanmnzsk8 - Spanish News Writer
    Julien Voisin (jvoisin/ap0) - French News Writer
    Kingpix - Italian News Writer
    Lukasz Gromanowski (lgro) - English News Writer
    Martin Otto (Atahualpa) - Podcaster, Public Outreach, German Translator
    Mickey Lyle (raevol) - Release Manager
    Nekochan - English News Writer
    penguinroad - Indonesian News Writer
    Pithorn - Chinese News Writer
    sir_herrbatka - Polish News Writer
    spyboot - German Translator
    Tom Koenderink (Okulo) - English News Writer

Website
-------

    Lukasz Gromanowski (Lgro) - Website Administrator
    Ryan Sardonic (Wry) - Wiki Editor
    sir_herrbatka - Forum Administrator

Formula Research
----------------

    Hrnchamd
    Epsilon
    fragonard
    Greendogo
    HiPhish
    modred11
    Myckel
    natirips
    Sadler

Artwork
-------

    Necrod - OpenMW Logo
    Mickey Lyle (raevol) - Wordpress Theme
    Tom Koenderink (Okulo), SirHerrbatka, crysthala, Shnatsel, Lamoot - OpenMW Editor Icons

Additional Credits
------------------
In this section we would like to thank people not part of OpenMW for their work.

Thanks to Maxim Nikolaev,
for allowing us to use his excellent Morrowind fan-art on our website and in other places.

Thanks to DokterDume,
for kindly providing us with the Moon and Star logo, used as the application icon and project logo.

Thanks to Kevin Ryan,
for creating the icon used for the Data Files tab of the OpenMW Launcher.

Thanks to DejaVu team,
for their DejaVuLGCSansMono fontface, see DejaVu Font License.txt for their license terms.
